==> ejc-assistrmat-api-3.0.0-20230518.055358-376-sources.jar: com/ejianc/business/outrmat/settle/vo/OutRmatAccReciReportVO.java <==
package com.ejianc.business.outrmat.settle.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author CJ
 * @Description:
 * @date 2023/4/23 19:15
 */
public class OutRmatAccReciReportVO implements Serializable {

    private static final long serialVersionUID = 2195304443222705805L;

    private Long contractId;
    private String contractCode;
    private String contractName;
    private String contractTypeName;
    private Long contractCategoryId;
    private String contractCategoryName;
    private BigDecimal contractTaxMny;
    private BigDecimal contractMny;
    private BigDecimal contractTax;
    private BigDecimal contractTaxMnyInW;
    private Long supplierId;
    private String supplierName;
    private String contractPckUrl;
    private BigDecimal curSettleTaxMny;
    private BigDecimal curSettleMny;
    private BigDecimal curSettleTax;
    private Date curSettleDate;
    private BigDecimal totalSettleTaxMnyThisYear;
    private BigDecimal totalSettleMnyThisYear;
    private BigDecimal totalSettleTaxThisYear;
    private BigDecimal totalStartSettleTaxMny;
    private BigDecimal totalStartSettleMny;
    private BigDecimal totalStartSettleTax;
    private BigDecimal totalSettleTaxMnyLastYear;
    private BigDecimal totalSettleMnyLastYear;
    private BigDecimal totalSettleTaxLastYear;
    private BigDecimal curRegisterMny;
    private BigDecimal totalRegisterMnyThisYear;
    private BigDecimal totalStartRegisterMny;
    private BigDecimal totalRegisterMnyLastYear;
    private BigDecimal registerScale;
    private BigDecimal overRegisterMny;
    private BigDecimal settleOverRegisterMnyLastYear;
    private String contractIds;
    private String settleIds;
    private String payRegisterIds;
    private String curSettleDateStr;
    private Long orgId;
    private String orgName;
    private Long parentOrgId;
    private String projectName;
    private Long projectId;
    private String projectCode;
    private String projectStateName;

    private Date baseSignDate; //首次合同签订时间
    private BigDecimal lastTotalOverMny; //截至上期累计欠款： 累计欠款 - 本期欠款
    private BigDecimal curAllotTaxMny; //本期调拨金额
    private BigDecimal curAllotMny; //本期调拨金额（无税）
    private BigDecimal curAllotTax; //本期调拨税额
    private BigDecimal totalAllotTaxMnyThisYear; //本年调拨金额（含税）
    private BigDecimal totalAllotMnyThisYear; //本年调拨金额（无税）
    private BigDecimal totalAllotTaxThisYear; //本年调拨税额
    private BigDecimal totalStartAllotTaxMny; //累计调拨金额（含税）
    private BigDecimal totalStartAllotMny; //累计调拨金额（无税）
    private BigDecimal totalStartAllotTax; //累计调拨税额
    private BigDecimal totalOverMny; //累计欠款合计：开累结算 - 开累收款
    private BigDecimal curOverMny; //本期欠款：本期结算 - 本期收款
    private String baseSignDateStr;

    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getProjectStateName() {
        return projectStateName;
    }

    public void setProjectStateName(String projectStateName) {
        this.projectStateName = projectStateName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getBaseSignDateStr() {
        return baseSignDateStr;
    }

    public void setBaseSignDateStr(String baseSignDateStr) {
        this.baseSignDateStr = baseSignDateStr;
    }

    public BigDecimal getTotalRegisterMnyThisYear() {
        return totalRegisterMnyThisYear;
    }

    public void setTotalRegisterMnyThisYear(BigDecimal totalRegisterMnyThisYear) {
        this.totalRegisterMnyThisYear = totalRegisterMnyThisYear;
    }

    public BigDecimal getTotalAllotTaxMnyThisYear() {
        return totalAllotTaxMnyThisYear;
    }

    public void setTotalAllotTaxMnyThisYear(BigDecimal totalAllotTaxMnyThisYear) {
        this.totalAllotTaxMnyThisYear = totalAllotTaxMnyThisYear;
    }

    public BigDecimal getTotalAllotMnyThisYear() {
        return totalAllotMnyThisYear;
    }

    public void setTotalAllotMnyThisYear(BigDecimal totalAllotMnyThisYear) {
        this.totalAllotMnyThisYear = totalAllotMnyThisYear;
    }

    public BigDecimal getTotalAllotTaxThisYear() {
        return totalAllotTaxThisYear;
    }

    public void setTotalAllotTaxThisYear(BigDecimal totalAllotTaxThisYear) {
        this.totalAllotTaxThisYear = totalAllotTaxThisYear;
    }

    public BigDecimal getTotalStartAllotTaxMny() {
        return totalStartAllotTaxMny;
    }

    public void setTotalStartAllotTaxMny(BigDecimal totalStartAllotTaxMny) {
        this.totalStartAllotTaxMny = totalStartAllotTaxMny;
    }

    public BigDecimal getTotalStartAllotMny() {
        return totalStartAllotMny;
    }

    public void setTotalStartAllotMny(BigDecimal totalStartAllotMny) {
        this.totalStartAllotMny = totalStartAllotMny;
    }

    public BigDecimal getTotalStartAllotTax() {
        return totalStartAllotTax;
    }

    public void setTotalStartAllotTax(BigDecimal totalStartAllotTax) {
        this.totalStartAllotTax = totalStartAllotTax;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractTypeName() {
        return contractTypeName;
    }

    public void setContractTypeName(String contractTypeName) {
        this.contractTypeName = contractTypeName;
    }

    public Long getContractCategoryId() {
        return contractCategoryId;
    }

    public void setContractCategoryId(Long contractCategoryId) {
        this.contractCategoryId = contractCategoryId;
    }

    public String getContractCategoryName() {
        return contractCategoryName;
    }

    public void setContractCategoryName(String contractCategoryName) {
        this.contractCategoryName = contractCategoryName;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public BigDecimal getContractTax() {
        return contractTax;
    }

    public void setContractTax(BigDecimal contractTax) {
        this.contractTax = contractTax;
    }

    public BigDecimal getContractTaxMnyInW() {
        return contractTaxMnyInW;
    }

    public void setContractTaxMnyInW(BigDecimal contractTaxMnyInW) {
        this.contractTaxMnyInW = contractTaxMnyInW;
    }

    @ReferSerialTransfer(referCode = "support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getContractPckUrl() {
        return contractPckUrl;
    }

    public void setContractPckUrl(String contractPckUrl) {
        this.contractPckUrl = contractPckUrl;
    }

    public BigDecimal getCurSettleTaxMny() {
        return curSettleTaxMny;
    }

    public void setCurSettleTaxMny(BigDecimal curSettleTaxMny) {
        this.curSettleTaxMny = curSettleTaxMny;
    }

    public BigDecimal getCurSettleMny() {
        return curSettleMny;
    }

    public void setCurSettleMny(BigDecimal curSettleMny) {
        this.curSettleMny = curSettleMny;
    }

    public BigDecimal getCurSettleTax() {
        return curSettleTax;
    }

    public void setCurSettleTax(BigDecimal curSettleTax) {
        this.curSettleTax = curSettleTax;
    }

    public Date getCurSettleDate() {
        return curSettleDate;
    }

    public void setCurSettleDate(Date curSettleDate) {
        this.curSettleDate = curSettleDate;
    }

    public BigDecimal getTotalSettleTaxMnyThisYear() {
        return totalSettleTaxMnyThisYear;
    }

    public void setTotalSettleTaxMnyThisYear(BigDecimal totalSettleTaxMnyThisYear) {
        this.totalSettleTaxMnyThisYear = totalSettleTaxMnyThisYear;
    }

    public BigDecimal getTotalSettleMnyThisYear() {
        return totalSettleMnyThisYear;
    }

    public void setTotalSettleMnyThisYear(BigDecimal totalSettleMnyThisYear) {
        this.totalSettleMnyThisYear = totalSettleMnyThisYear;
    }

    public BigDecimal getTotalSettleTaxThisYear() {
        return totalSettleTaxThisYear;
    }

    public void setTotalSettleTaxThisYear(BigDecimal totalSettleTaxThisYear) {
        this.totalSettleTaxThisYear = totalSettleTaxThisYear;
    }

    public BigDecimal getTotalStartSettleTaxMny() {
        return totalStartSettleTaxMny;
    }

    public void setTotalStartSettleTaxMny(BigDecimal totalStartSettleTaxMny) {
        this.totalStartSettleTaxMny = totalStartSettleTaxMny;
    }

    public BigDecimal getTotalStartSettleMny() {
        return totalStartSettleMny;
    }

    public void setTotalStartSettleMny(BigDecimal totalStartSettleMny) {
        this.totalStartSettleMny = totalStartSettleMny;
    }

    public BigDecimal getTotalStartSettleTax() {
        return totalStartSettleTax;
    }

    public void setTotalStartSettleTax(BigDecimal totalStartSettleTax) {
        this.totalStartSettleTax = totalStartSettleTax;
    }

    public BigDecimal getTotalSettleTaxMnyLastYear() {
        return totalSettleTaxMnyLastYear;
    }

    public void setTotalSettleTaxMnyLastYear(BigDecimal totalSettleTaxMnyLastYear) {
        this.totalSettleTaxMnyLastYear = totalSettleTaxMnyLastYear;
    }

    public BigDecimal getTotalSettleMnyLastYear() {
        return totalSettleMnyLastYear;
    }

    public void setTotalSettleMnyLastYear(BigDecimal totalSettleMnyLastYear) {
        this.totalSettleMnyLastYear = totalSettleMnyLastYear;
    }

    public BigDecimal getTotalSettleTaxLastYear() {
        return totalSettleTaxLastYear;
    }

    public void setTotalSettleTaxLastYear(BigDecimal totalSettleTaxLastYear) {
        this.totalSettleTaxLastYear = totalSettleTaxLastYear;
    }

    public BigDecimal getCurRegisterMny() {
        return curRegisterMny;
    }

    public void setCurRegisterMny(BigDecimal curRegisterMny) {
        this.curRegisterMny = curRegisterMny;
    }

    public BigDecimal getTotalStartRegisterMny() {
        return totalStartRegisterMny;
    }

    public void setTotalStartRegisterMny(BigDecimal totalStartRegisterMny) {
        this.totalStartRegisterMny = totalStartRegisterMny;
    }

    public BigDecimal getTotalRegisterMnyLastYear() {
        return totalRegisterMnyLastYear;
    }

    public void setTotalRegisterMnyLastYear(BigDecimal totalRegisterMnyLastYear) {
        this.totalRegisterMnyLastYear = totalRegisterMnyLastYear;
    }

    public BigDecimal getRegisterScale() {
        return registerScale;
    }

    public void setRegisterScale(BigDecimal registerScale) {
        this.registerScale = registerScale;
    }

    public BigDecimal getOverRegisterMny() {
        return overRegisterMny;
    }

    public void setOverRegisterMny(BigDecimal overRegisterMny) {
        this.overRegisterMny = overRegisterMny;
    }

    public BigDecimal getSettleOverRegisterMnyLastYear() {
        return settleOverRegisterMnyLastYear;
    }

    public void setSettleOverRegisterMnyLastYear(BigDecimal settleOverRegisterMnyLastYear) {
        this.settleOverRegisterMnyLastYear = settleOverRegisterMnyLastYear;
    }

    public String getContractIds() {
        return contractIds;
    }

    public void setContractIds(String contractIds) {
        this.contractIds = contractIds;
    }

    public String getSettleIds() {
        return settleIds;
    }

    public void setSettleIds(String settleIds) {
        this.settleIds = settleIds;
    }

    public String getPayRegisterIds() {
        return payRegisterIds;
    }

    public void setPayRegisterIds(String payRegisterIds) {
        this.payRegisterIds = payRegisterIds;
    }

    public String getCurSettleDateStr() {
        return curSettleDateStr;
    }

    public void setCurSettleDateStr(String curSettleDateStr) {
        this.curSettleDateStr = curSettleDateStr;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getBaseSignDate() {
        return baseSignDate;
    }

    public void setBaseSignDate(Date baseSignDate) {
        this.baseSignDate = baseSignDate;
    }

    public BigDecimal getLastTotalOverMny() {
        return lastTotalOverMny;
    }

    public void setLastTotalOverMny(BigDecimal lastTotalOverMny) {
        this.lastTotalOverMny = lastTotalOverMny;
    }

    public BigDecimal getCurAllotTaxMny() {
        return curAllotTaxMny;
    }

    public void setCurAllotTaxMny(BigDecimal curAllotTaxMny) {
        this.curAllotTaxMny = curAllotTaxMny;
    }

    public BigDecimal getCurAllotMny() {
        return curAllotMny;
    }

    public void setCurAllotMny(BigDecimal curAllotMny) {
        this.curAllotMny = curAllotMny;
    }

    public BigDecimal getCurAllotTax() {
        return curAllotTax;
    }

    public void setCurAllotTax(BigDecimal curAllotTax) {
        this.curAllotTax = curAllotTax;
    }

    public BigDecimal getTotalOverMny() {
        return totalOverMny;
    }

    public void setTotalOverMny(BigDecimal totalOverMny) {
        this.totalOverMny = totalOverMny;
    }

    public BigDecimal getCurOverMny() {
        return curOverMny;
    }

    public void setCurOverMny(BigDecimal curOverMny) {
        this.curOverMny = curOverMny;
    }
}

==> ejc-assistrmat-api-3.0.0-20230531.073911-389-sources.jar: com/ejianc/business/outrmat/settle/vo/OutRmatAccReciReportVO.java <==
package com.ejianc.business.outrmat.settle.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author CJ
 * @Description:
 * @date 2023/4/23 19:15
 */
public class OutRmatAccReciReportVO implements Serializable {

    private static final long serialVersionUID = 2195304443222705805L;

    private Long contractId;
    private String contractCode;
    private String contractName;
    private String contractTypeName;
    private Long contractCategoryId;
    private String contractCategoryName;
    private BigDecimal contractTaxMny;
    private BigDecimal contractMny;
    private BigDecimal contractTax;
    private BigDecimal contractTaxMnyInW;
    private Long supplierId;
    private String supplierName;
    private String contractPckUrl;
    private BigDecimal curSettleTaxMny;
    private BigDecimal curSettleMny;
    private BigDecimal curSettleTax;
    private Date curSettleDate;
    private BigDecimal totalSettleTaxMnyThisYear;
    private BigDecimal totalSettleMnyThisYear;
    private BigDecimal totalSettleTaxThisYear;
    private BigDecimal totalStartSettleTaxMny;
    private BigDecimal totalStartSettleMny;
    private BigDecimal totalStartSettleTax;
    private BigDecimal totalSettleTaxMnyLastYear;
    private BigDecimal totalSettleMnyLastYear;
    private BigDecimal totalSettleTaxLastYear;
    private BigDecimal curRegisterMny;
    private BigDecimal totalRegisterMnyThisYear;
    private BigDecimal totalStartRegisterMny;
    private BigDecimal totalRegisterMnyLastYear;
    private BigDecimal registerScale;
    private BigDecimal overRegisterMny;
    private BigDecimal settleOverRegisterMnyLastYear;
    private String contractIds;
    private String settleIds;
    private String payRegisterIds;
    private String curSettleDateStr;
    private Long orgId;
    private String orgName;
    private Long parentOrgId;
    private String projectName;
    private Long projectId;
    private String projectCode;
    private String projectStateName;
    private Long firstPartyId; //甲方Id
    private String firstPartyName; //甲方名称

    private Date baseSignDate; //首次合同签订时间
    private BigDecimal lastTotalOverMny; //截至上期累计欠款： 累计欠款 - 本期欠款
    private BigDecimal curAllotTaxMny; //本期调拨金额
    private BigDecimal curAllotMny; //本期调拨金额（无税）
    private BigDecimal curAllotTax; //本期调拨税额
    private BigDecimal totalAllotTaxMnyThisYear; //本年调拨金额（含税）
    private BigDecimal totalAllotMnyThisYear; //本年调拨金额（无税）
    private BigDecimal totalAllotTaxThisYear; //本年调拨税额
    private BigDecimal totalStartAllotTaxMny; //累计调拨金额（含税）
    private BigDecimal totalStartAllotMny; //累计调拨金额（无税）
    private BigDecimal totalStartAllotTax; //累计调拨税额
    private BigDecimal totalOverMny; //累计欠款合计：开累结算 - 开累收款
    private BigDecimal curOverMny; //本期欠款：本期结算 - 本期收款
    private String baseSignDateStr;

    @ReferSerialTransfer(referCode="support-supplier")
    public Long getFirstPartyId() {
        return firstPartyId;
    }

    public void setFirstPartyId(Long firstPartyId) {
        this.firstPartyId = firstPartyId;
    }

    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getProjectStateName() {
        return projectStateName;
    }

    public void setProjectStateName(String projectStateName) {
        this.projectStateName = projectStateName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getBaseSignDateStr() {
        return baseSignDateStr;
    }

    public void setBaseSignDateStr(String baseSignDateStr) {
        this.baseSignDateStr = baseSignDateStr;
    }

    public BigDecimal getTotalRegisterMnyThisYear() {
        return totalRegisterMnyThisYear;
    }

    public void setTotalRegisterMnyThisYear(BigDecimal totalRegisterMnyThisYear) {
        this.totalRegisterMnyThisYear = totalRegisterMnyThisYear;
    }

    public BigDecimal getTotalAllotTaxMnyThisYear() {
        return totalAllotTaxMnyThisYear;
    }

    public void setTotalAllotTaxMnyThisYear(BigDecimal totalAllotTaxMnyThisYear) {
        this.totalAllotTaxMnyThisYear = totalAllotTaxMnyThisYear;
    }

    public BigDecimal getTotalAllotMnyThisYear() {
        return totalAllotMnyThisYear;
    }

    public void setTotalAllotMnyThisYear(BigDecimal totalAllotMnyThisYear) {
        this.totalAllotMnyThisYear = totalAllotMnyThisYear;
    }

    public BigDecimal getTotalAllotTaxThisYear() {
        return totalAllotTaxThisYear;
    }

    public void setTotalAllotTaxThisYear(BigDecimal totalAllotTaxThisYear) {
        this.totalAllotTaxThisYear = totalAllotTaxThisYear;
    }

    public BigDecimal getTotalStartAllotTaxMny() {
        return totalStartAllotTaxMny;
    }

    public void setTotalStartAllotTaxMny(BigDecimal totalStartAllotTaxMny) {
        this.totalStartAllotTaxMny = totalStartAllotTaxMny;
    }

    public BigDecimal getTotalStartAllotMny() {
        return totalStartAllotMny;
    }

    public void setTotalStartAllotMny(BigDecimal totalStartAllotMny) {
        this.totalStartAllotMny = totalStartAllotMny;
    }

    public BigDecimal getTotalStartAllotTax() {
        return totalStartAllotTax;
    }

    public void setTotalStartAllotTax(BigDecimal totalStartAllotTax) {
        this.totalStartAllotTax = totalStartAllotTax;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractTypeName() {
        return contractTypeName;
    }

    public void setContractTypeName(String contractTypeName) {
        this.contractTypeName = contractTypeName;
    }

    public Long getContractCategoryId() {
        return contractCategoryId;
    }

    public void setContractCategoryId(Long contractCategoryId) {
        this.contractCategoryId = contractCategoryId;
    }

    public String getContractCategoryName() {
        return contractCategoryName;
    }

    public void setContractCategoryName(String contractCategoryName) {
        this.contractCategoryName = contractCategoryName;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public BigDecimal getContractTax() {
        return contractTax;
    }

    public void setContractTax(BigDecimal contractTax) {
        this.contractTax = contractTax;
    }

    public BigDecimal getContractTaxMnyInW() {
        return contractTaxMnyInW;
    }

    public void setContractTaxMnyInW(BigDecimal contractTaxMnyInW) {
        this.contractTaxMnyInW = contractTaxMnyInW;
    }

    @ReferSerialTransfer(referCode = "support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getContractPckUrl() {
        return contractPckUrl;
    }

    public void setContractPckUrl(String contractPckUrl) {
        this.contractPckUrl = contractPckUrl;
    }

    public BigDecimal getCurSettleTaxMny() {
        return curSettleTaxMny;
    }

    public void setCurSettleTaxMny(BigDecimal curSettleTaxMny) {
        this.curSettleTaxMny = curSettleTaxMny;
    }

    public BigDecimal getCurSettleMny() {
        return curSettleMny;
    }

    public void setCurSettleMny(BigDecimal curSettleMny) {
        this.curSettleMny = curSettleMny;
    }

    public BigDecimal getCurSettleTax() {
        return curSettleTax;
    }

    public void setCurSettleTax(BigDecimal curSettleTax) {
        this.curSettleTax = curSettleTax;
    }

    public Date getCurSettleDate() {
        return curSettleDate;
    }

    public void setCurSettleDate(Date curSettleDate) {
        this.curSettleDate = curSettleDate;
    }

    public BigDecimal getTotalSettleTaxMnyThisYear() {
        return totalSettleTaxMnyThisYear;
    }

    public void setTotalSettleTaxMnyThisYear(BigDecimal totalSettleTaxMnyThisYear) {
        this.totalSettleTaxMnyThisYear = totalSettleTaxMnyThisYear;
    }

    public BigDecimal getTotalSettleMnyThisYear() {
        return totalSettleMnyThisYear;
    }

    public void setTotalSettleMnyThisYear(BigDecimal totalSettleMnyThisYear) {
        this.totalSettleMnyThisYear = totalSettleMnyThisYear;
    }

    public BigDecimal getTotalSettleTaxThisYear() {
        return totalSettleTaxThisYear;
    }

    public void setTotalSettleTaxThisYear(BigDecimal totalSettleTaxThisYear) {
        this.totalSettleTaxThisYear = totalSettleTaxThisYear;
    }

    public BigDecimal getTotalStartSettleTaxMny() {
        return totalStartSettleTaxMny;
    }

    public void setTotalStartSettleTaxMny(BigDecimal totalStartSettleTaxMny) {
        this.totalStartSettleTaxMny = totalStartSettleTaxMny;
    }

    public BigDecimal getTotalStartSettleMny() {
        return totalStartSettleMny;
    }

    public void setTotalStartSettleMny(BigDecimal totalStartSettleMny) {
        this.totalStartSettleMny = totalStartSettleMny;
    }

    public BigDecimal getTotalStartSettleTax() {
        return totalStartSettleTax;
    }

    public void setTotalStartSettleTax(BigDecimal totalStartSettleTax) {
        this.totalStartSettleTax = totalStartSettleTax;
    }

    public BigDecimal getTotalSettleTaxMnyLastYear() {
        return totalSettleTaxMnyLastYear;
    }

    public void setTotalSettleTaxMnyLastYear(BigDecimal totalSettleTaxMnyLastYear) {
        this.totalSettleTaxMnyLastYear = totalSettleTaxMnyLastYear;
    }

    public BigDecimal getTotalSettleMnyLastYear() {
        return totalSettleMnyLastYear;
    }

    public void setTotalSettleMnyLastYear(BigDecimal totalSettleMnyLastYear) {
        this.totalSettleMnyLastYear = totalSettleMnyLastYear;
    }

    public BigDecimal getTotalSettleTaxLastYear() {
        return totalSettleTaxLastYear;
    }

    public void setTotalSettleTaxLastYear(BigDecimal totalSettleTaxLastYear) {
        this.totalSettleTaxLastYear = totalSettleTaxLastYear;
    }

    public BigDecimal getCurRegisterMny() {
        return curRegisterMny;
    }

    public void setCurRegisterMny(BigDecimal curRegisterMny) {
        this.curRegisterMny = curRegisterMny;
    }

    public BigDecimal getTotalStartRegisterMny() {
        return totalStartRegisterMny;
    }

    public void setTotalStartRegisterMny(BigDecimal totalStartRegisterMny) {
        this.totalStartRegisterMny = totalStartRegisterMny;
    }

    public BigDecimal getTotalRegisterMnyLastYear() {
        return totalRegisterMnyLastYear;
    }

    public void setTotalRegisterMnyLastYear(BigDecimal totalRegisterMnyLastYear) {
        this.totalRegisterMnyLastYear = totalRegisterMnyLastYear;
    }

    public BigDecimal getRegisterScale() {
        return registerScale;
    }

    public void setRegisterScale(BigDecimal registerScale) {
        this.registerScale = registerScale;
    }

    public BigDecimal getOverRegisterMny() {
        return overRegisterMny;
    }

    public void setOverRegisterMny(BigDecimal overRegisterMny) {
        this.overRegisterMny = overRegisterMny;
    }

    public BigDecimal getSettleOverRegisterMnyLastYear() {
        return settleOverRegisterMnyLastYear;
    }

    public void setSettleOverRegisterMnyLastYear(BigDecimal settleOverRegisterMnyLastYear) {
        this.settleOverRegisterMnyLastYear = settleOverRegisterMnyLastYear;
    }

    public String getContractIds() {
        return contractIds;
    }

    public void setContractIds(String contractIds) {
        this.contractIds = contractIds;
    }

    public String getSettleIds() {
        return settleIds;
    }

    public void setSettleIds(String settleIds) {
        this.settleIds = settleIds;
    }

    public String getPayRegisterIds() {
        return payRegisterIds;
    }

    public void setPayRegisterIds(String payRegisterIds) {
        this.payRegisterIds = payRegisterIds;
    }

    public String getCurSettleDateStr() {
        return curSettleDateStr;
    }

    public void setCurSettleDateStr(String curSettleDateStr) {
        this.curSettleDateStr = curSettleDateStr;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getBaseSignDate() {
        return baseSignDate;
    }

    public void setBaseSignDate(Date baseSignDate) {
        this.baseSignDate = baseSignDate;
    }

    public BigDecimal getLastTotalOverMny() {
        return lastTotalOverMny;
    }

    public void setLastTotalOverMny(BigDecimal lastTotalOverMny) {
        this.lastTotalOverMny = lastTotalOverMny;
    }

    public BigDecimal getCurAllotTaxMny() {
        return curAllotTaxMny;
    }

    public void setCurAllotTaxMny(BigDecimal curAllotTaxMny) {
        this.curAllotTaxMny = curAllotTaxMny;
    }

    public BigDecimal getCurAllotMny() {
        return curAllotMny;
    }

    public void setCurAllotMny(BigDecimal curAllotMny) {
        this.curAllotMny = curAllotMny;
    }

    public BigDecimal getCurAllotTax() {
        return curAllotTax;
    }

    public void setCurAllotTax(BigDecimal curAllotTax) {
        this.curAllotTax = curAllotTax;
    }

    public BigDecimal getTotalOverMny() {
        return totalOverMny;
    }

    public void setTotalOverMny(BigDecimal totalOverMny) {
        this.totalOverMny = totalOverMny;
    }

    public BigDecimal getCurOverMny() {
        return curOverMny;
    }

    public void setCurOverMny(BigDecimal curOverMny) {
        this.curOverMny = curOverMny;
    }
}
